/** @file
 * @brief DYNDNS Service class header. This class represents the DYNDNS service.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef ServiceDyndns_H
#define ServiceDyndns_H

#include "service.hpp"
#include "logger.hpp"
#include "httphelper.hpp"

#include <boost/shared_ptr.hpp>
#include <string>


class ServiceDyndns : public Service
{

private:

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & ar, const unsigned int version)
    {
        ar & boost::serialization::base_object<Service>(*this);
    }

    std::string AlternativeServer;  // Needed for NO-IP
    std::string BaseUrl;

    HTTPHelper::Ptr HTTPHelp;

    std::string assemble_base_url(const std::string& fqhn) const;

public:

    typedef boost::shared_ptr<ServiceDyndns> Ptr;

    ServiceDyndns();

    ServiceDyndns(const std::string& _protocol, const std::string& _hostname, const std::string& _login, const std::string& _password, const Logger::Ptr& _logger, const int _update_interval, const int _max_updates_within_interval, const int _max_equal_updates_in_succession, const int dns_cache_ttl, const std::string& proxy, const int proxy_port, const std::string& _alternative_server = "");

    ~ServiceDyndns();

    int perform_update(const std::string& ip);

};

#endif
